PAWpySeed: /home/kyle/Research/projects/pawpyseed/pawpyseed/core/projector.py File Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- File List
- File Members

Classes | Namespaces | Functions | Variables
projector.py File Reference

## Classes
class | pawpyseed.core.projector.CopyPseudoWavefunction
class | pawpyseed.core.projector.Projector

## Namespaces
| pawpyseed.core.projector
| Defines the Projector class, an extension of the Wavefunction class for evaluating AE projection operators.

## Functions
def | pawpyseed.core.projector.make_c_ops (op_nums, symmops)
def | pawpyseed.core.projector.copy_wf (rwf, wf_ptr, allkpts, weights, setup_projectors=False, free_ref=False)

## Variables
int | pawpyseed.core.projector.OPSIZE = 9